@@ -14,9 +14,7 @@ describe 'nova::compute::libvirt' do
     describe 'with default parameters' do
 
       let :params do
-        {
-          :libvirt_cpu_model_extra_flags  => 'pcid,pdpe1gb',
-        }
+        {}
       end
 
       it { is_expected.to contain_class('nova::params')}
@@ -32,7 +30,7 @@ describe 'nova::compute::libvirt' do
 
       it {
         is_expected.to contain_package('libvirt').with(
-          :name   => 'libvirtd',
+          :name   => 'libvirt-bin',
           :ensure => 'present'
         )
         is_expected.to contain_package('libvirt').that_requires('Anchor[nova::install::begin]')
@@ -51,42 +49,47 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('DEFAULT/preallocate_images').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/virt_type').with_value('kvm')}
       it { is_expected.to contain_nova_config('libvirt/cpu_mode').with_value('host-model')}
+      it { is_expected.to contain_nova_config('libvirt/cpu_models').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/cpu_model').with_ensure('absent')}
-      it { is_expected.to contain_nova_config('libvirt/cpu_model_extra_flags').with_ensure('pcid,pdpe1gb')}
-      it { is_expected.to contain_nova_config('libvirt/snapshot_image_format').with_ensure('absent')}
+      it { is_expected.to contain_nova_config('libvirt/cpu_model_extra_flags').with_ensure('absent')}
+      it { is_expected.to contain_nova_config('libvirt/snapshot_image_format').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/disk_cachemodes').with_ensure('absent')}
       it { is_expected.to contain_nova_config('libvirt/inject_password').with_value(false)}
       it { is_expected.to contain_nova_config('libvirt/inject_key').with_value(false)}
       it { is_expected.to contain_nova_config('libvirt/inject_partition').with_value(-2)}
       it { is_expected.to contain_nova_config('vnc/server_listen').with_value('127.0.0.1')}
-      it { is_expected.to contain_nova_config('DEFAULT/remove_unused_base_images').with_ensure('absent')}
-      it { is_expected.to contain_nova_config('DEFAULT/remove_unused_original_minimum_age_seconds').with_ensure('absent')}
-      it { is_expected.to contain_nova_config('libvirt/remove_unused_resized_minimum_age_seconds').with_ensure('absent')}
+      it { is_expected.to contain_nova_config('DEFAULT/remove_unused_base_images').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('DEFAULT/remove_unused_original_minimum_age_seconds').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/remove_unused_resized_minimum_age_seconds').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/rx_queue_size').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/tx_queue_size').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/volume_use_multipath').with_value('<SERVICE DEFAULT>')}
-      it { is_expected.to contain_nova_config('libvirt/nfs_mount_options').with_ensure('<SERVICE DEFAULT>')}
-      it { is_expected.to contain_nova_config('libvirt/num_pcie_ports').with_ensure('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/nfs_mount_options').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/num_pcie_ports').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/mem_stats_period_seconds').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/pmem_namespaces').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/swtpm_enabled').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/swtpm_user').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/swtpm_group').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_libvirtd_config('log_outputs').with_ensure('absent')}
       it { is_expected.to contain_libvirtd_config('log_filters').with_ensure('absent')}
       it { is_expected.to contain_libvirtd_config('tls_priority').with_ensure('absent')}
-      it { is_expected.to contain_libvirtd_config('pmem_namespaces').with_ensure('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_libvirtd_config('ovs_timeout').with_ensure('absent')}
     end
 
     describe 'with params' do
       let :params do
         { :ensure_package                             => 'latest',
-          :libvirt_virt_type                          => 'qemu',
+          :virt_type                                  => 'qemu',
           :vncserver_listen                           => '0.0.0.0',
-          :libvirt_cpu_mode                           => 'host-passthrough',
-          :libvirt_cpu_model                          => 'kvm64',
-          :libvirt_cpu_model_extra_flags              => 'pcid',
-          :libvirt_snapshot_image_format              => 'raw',
-          :libvirt_disk_cachemodes                    => ['file=directsync','block=none'],
-          :libvirt_hw_disk_discard                    => 'unmap',
-          :libvirt_hw_machine_type                    => 'x86_64=machinetype1,armv7l=machinetype2',
-          :libvirt_enabled_perf_events                => ['cmt', 'mbml', 'mbmt'],
+          :cpu_mode                                   => 'host-passthrough',
+          :cpu_models                                 => ['kvm64', 'qemu64'],
+          :cpu_model_extra_flags                      => 'pcid',
+          :snapshot_image_format                      => 'raw',
+          :disk_cachemodes                            => ['file=directsync','block=none'],
+          :hw_disk_discard                            => 'unmap',
+          :hw_machine_type                            => 'x86_64=machinetype1,armv7l=machinetype2',
+          :enabled_perf_events                        => ['cmt', 'mbml', 'mbmt'],
           :remove_unused_base_images                  => true,
           :remove_unused_resized_minimum_age_seconds  => 3600,
           :remove_unused_original_minimum_age_seconds => 3600,
@@ -95,16 +98,20 @@ describe 'nova::compute::libvirt' do
           :virtlog_service_name                       => 'virtlog',
           :compute_driver                             => 'libvirt.FoobarDriver',
           :preallocate_images                         => 'space',
-          :log_outputs                                => '1:file:/var/log/libvirt/libvirtd.log',
           :rx_queue_size                              => 512,
           :tx_queue_size                              => 1024,
           :volume_use_multipath                       => false,
           :nfs_mount_options                          => 'rw,intr,nolock',
           :num_pcie_ports                             => 16,
           :mem_stats_period_seconds                   => 20,
+          :pmem_namespaces                            => '128G:ns0|ns1|ns2|ns3',
+          :swtpm_enabled                              => true,
+          :swtpm_user                                 => 'libvirt',
+          :swtpm_group                                => 'libvirt',
+          :log_outputs                                => '1:file:/var/log/libvirt/libvirtd.log',
           :log_filters                                => '1:qemu',
           :tls_priority                               => 'NORMAL:-VERS-SSL3.0',
-          :pmem_namespaces                            => '128G:ns0|ns1|ns2|ns3'
+          :ovs_timeout                                => 10,
         }
       end
 
@@ -116,9 +123,10 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('DEFAULT/preallocate_images').with_value('space')}
       it { is_expected.to contain_nova_config('libvirt/virt_type').with_value('qemu')}
       it { is_expected.to contain_nova_config('libvirt/cpu_mode').with_value('host-passthrough')}
+      it { is_expected.to contain_nova_config('libvirt/cpu_models').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/cpu_model').with_ensure('absent')}
-      it { is_expected.to contain_nova_config('libvirt/cpu_model_extra_flags').with_ensure('pcid')}
-      it { is_expected.to contain_nova_config('libvirt/snapshot_image_format').with_ensure('absent')}
+      it { is_expected.to contain_nova_config('libvirt/cpu_model_extra_flags').with_value('pcid')}
+      it { is_expected.to contain_nova_config('libvirt/snapshot_image_format').with_value('raw')}
       it { is_expected.to contain_nova_config('libvirt/disk_cachemodes').with_value('file=directsync,block=none')}
       it { is_expected.to contain_nova_config('libvirt/hw_disk_discard').with_value('unmap')}
       it { is_expected.to contain_nova_config('libvirt/hw_machine_type').with_value('x86_64=machinetype1,armv7l=machinetype2')}
@@ -127,16 +135,20 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('DEFAULT/remove_unused_base_images').with_value(true)}
       it { is_expected.to contain_nova_config('DEFAULT/remove_unused_original_minimum_age_seconds').with_value(3600)}
       it { is_expected.to contain_nova_config('libvirt/remove_unused_resized_minimum_age_seconds').with_value(3600)}
-      it { is_expected.to contain_libvirtd_config('log_outputs').with_value("\"#{params[:log_outputs]}\"")}
       it { is_expected.to contain_nova_config('libvirt/rx_queue_size').with_value(512)}
       it { is_expected.to contain_nova_config('libvirt/tx_queue_size').with_value(1024)}
       it { is_expected.to contain_nova_config('libvirt/volume_use_multipath').with_value(false)}
       it { is_expected.to contain_nova_config('libvirt/nfs_mount_options').with_value('rw,intr,nolock')}
       it { is_expected.to contain_nova_config('libvirt/num_pcie_ports').with_value(16)}
       it { is_expected.to contain_nova_config('libvirt/mem_stats_period_seconds').with_value(20)}
-      it { is_expected.to contain_libvirtd_config('log_filters').with_value("\"#{params[:log_filters]}\"")}
-      it { is_expected.to contain_libvirtd_config('tls_priority').with_value("\"#{params[:tls_priority]}\"")}
-      it { is_expected.to contain_libvirtd_config('pmem_namespaces').with_value("128G:ns0|ns1|ns2|ns3")}
+      it { is_expected.to contain_nova_config('libvirt/pmem_namespaces').with_value("128G:ns0|ns1|ns2|ns3")}
+      it { is_expected.to contain_nova_config('libvirt/swtpm_enabled').with_value(true)}
+      it { is_expected.to contain_nova_config('libvirt/swtpm_user').with_value('libvirt')}
+      it { is_expected.to contain_nova_config('libvirt/swtpm_group').with_value('libvirt')}
+      it { is_expected.to contain_libvirtd_config('log_outputs').with_value('"1:file:/var/log/libvirt/libvirtd.log"')}
+      it { is_expected.to contain_libvirtd_config('log_filters').with_value('"1:qemu"')}
+      it { is_expected.to contain_libvirtd_config('tls_priority').with_value('"NORMAL:-VERS-SSL3.0"')}
+      it { is_expected.to contain_libvirtd_config('ovs_timeout').with_value(10)}
       it {
         is_expected.to contain_service('libvirt').with(
           :name     => 'custom_service',
@@ -160,19 +172,33 @@ describe 'nova::compute::libvirt' do
 
     describe 'with custom cpu_mode' do
       let :params do
-        { :libvirt_cpu_mode              => 'custom',
-          :libvirt_cpu_model             => 'kvm64',
-          :libvirt_cpu_model_extra_flags => 'pcid' }
+        { :cpu_mode              => 'custom',
+          :cpu_models            => ['kvm64', 'qemu64'],
+          :cpu_model_extra_flags => 'pcid' }
       end
 
       it { is_expected.to contain_nova_config('libvirt/cpu_mode').with_value('custom')}
-      it { is_expected.to contain_nova_config('libvirt/cpu_model').with_value('kvm64')}
+      it { is_expected.to contain_nova_config('libvirt/cpu_models').with_value('kvm64,qemu64')}
+      it { is_expected.to contain_nova_config('libvirt/cpu_model').with_ensure('absent')}
+      it { is_expected.to contain_nova_config('libvirt/cpu_model_extra_flags').with_value('pcid')}
+    end
+
+    describe 'with custom cpu_mode with deprecated libvirt_cpu_model' do
+      let :params do
+        { :cpu_mode              => 'custom',
+          :libvirt_cpu_model     => 'kvm64',
+          :cpu_model_extra_flags => 'pcid' }
+      end
+
+      it { is_expected.to contain_nova_config('libvirt/cpu_mode').with_value('custom')}
+      it { is_expected.to contain_nova_config('libvirt/cpu_models').with_value('kvm64')}
+      it { is_expected.to contain_nova_config('libvirt/cpu_model').with_ensure('absent')}
       it { is_expected.to contain_nova_config('libvirt/cpu_model_extra_flags').with_value('pcid')}
     end
 
     describe 'with qcow2 as snapshot_image_format' do
       let :params do
-        { :libvirt_snapshot_image_format => 'qcow2' }
+        { :snapshot_image_format => 'qcow2' }
       end
 
       it { is_expected.to contain_nova_config('libvirt/snapshot_image_format').with_value('qcow2')}
@@ -180,7 +206,7 @@ describe 'nova::compute::libvirt' do
 
     describe 'with qemu as virt_type' do
       let :params do
-        { :libvirt_virt_type => 'qemu' }
+        { :virt_type => 'qemu' }
       end
 
       it { is_expected.to contain_nova_config('libvirt/cpu_mode').with_value('none')}
@@ -197,10 +223,6 @@ describe 'nova::compute::libvirt' do
         it { is_expected.to contain_class('nova::migration::libvirt')}
         it { is_expected.to contain_nova_config('vnc/server_listen').with_value('0.0.0.0')}
         it { is_expected.to contain_file_line('/etc/default/libvirtd libvirtd opts').with(:line => libvirt_options) }
-        it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tls').with(:line => "listen_tls = 0") }
-        it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tcp').with(:line => "listen_tcp = 1") }
-        it { is_expected.not_to contain_file_line('/etc/libvirt/libvirtd.conf auth_tls')}
-        it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf auth_tcp').with(:line => "auth_tcp = \"none\"") }
       end
 
       context 'with vncserver_listen set to ::0' do
@@ -212,10 +234,6 @@ describe 'nova::compute::libvirt' do
         it { is_expected.to contain_class('nova::migration::libvirt')}
         it { is_expected.to contain_nova_config('vnc/server_listen').with_value('::0')}
         it { is_expected.to contain_file_line('/etc/default/libvirtd libvirtd opts').with(:line => libvirt_options) }
-        it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tls').with(:line => "listen_tls = 0") }
-        it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tcp').with(:line => "listen_tcp = 1") }
-        it { is_expected.not_to contain_file_line('/etc/libvirt/libvirtd.conf auth_tls')}
-        it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf auth_tcp').with(:line => "auth_tcp = \"none\"") }
       end
 
       context 'with custom libvirt service name on Debian platforms' do
@@ -278,7 +296,7 @@ describe 'nova::compute::libvirt' do
         :ensure => 'running',
         :enable => true,
         :before => ['Service[libvirt]'],
-        :name   => 'messagebus'
+        :name   => 'dbus'
       ) }
 
       describe 'on rhel 7' do
@@ -302,20 +320,20 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/inject_key').with_value(false)}
       it { is_expected.to contain_nova_config('libvirt/inject_partition').with_value(-2)}
       it { is_expected.to contain_nova_config('vnc/server_listen').with_value('127.0.0.1')}
-      it { is_expected.to contain_nova_config('DEFAULT/remove_unused_base_images').with_ensure('absent')}
-      it { is_expected.to contain_nova_config('DEFAULT/remove_unused_original_minimum_age_seconds').with_ensure('absent')}
-      it { is_expected.to contain_nova_config('libvirt/remove_unused_resized_minimum_age_seconds').with_ensure('absent')}
-      it { is_expected.to contain_nova_config('libvirt/nfs_mount_options').with_ensure('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('DEFAULT/remove_unused_base_images').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('DEFAULT/remove_unused_original_minimum_age_seconds').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/remove_unused_resized_minimum_age_seconds').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/nfs_mount_options').with_value('<SERVICE DEFAULT>')}
     end
 
     describe 'with params' do
       let :params do
-        { :libvirt_virt_type                          => 'qemu',
+        { :virt_type                                  => 'qemu',
           :vncserver_listen                           => '0.0.0.0',
           :remove_unused_base_images                  => true,
           :remove_unused_resized_minimum_age_seconds  => 3600,
           :remove_unused_original_minimum_age_seconds => 3600,
-          :libvirt_enabled_perf_events                => ['cmt', 'mbml', 'mbmt'],
+          :enabled_perf_events                        => ['cmt', 'mbml', 'mbmt'],
           :nfs_mount_options                          => 'rw,intr,nolock',
           :mem_stats_period_seconds                   => 20,
         }
@@ -346,10 +364,6 @@ describe 'nova::compute::libvirt' do
         it { is_expected.to contain_class('nova::migration::libvirt')}
         it { is_expected.to contain_nova_config('vnc/server_listen').with_value('0.0.0.0')}
         it { is_expected.to contain_file_line('/etc/sysconfig/libvirtd libvirtd args').with(:line => 'LIBVIRTD_ARGS="--listen"') }
-        it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tls').with(:line => "listen_tls = 0") }
-        it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tcp').with(:line => "listen_tcp = 1") }
-        it { is_expected.not_to contain_file_line('/etc/libvirt/libvirtd.conf auth_tls')}
-        it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf auth_tcp').with(:line => "auth_tcp = \"none\"") }
       end
 
       context 'with vncserver_listen set to ::0' do
@@ -361,10 +375,6 @@ describe 'nova::compute::libvirt' do
         it { is_expected.to contain_class('nova::migration::libvirt')}
         it { is_expected.to contain_nova_config('vnc/server_listen').with_value('::0')}
         it { is_expected.to contain_file_line('/etc/sysconfig/libvirtd libvirtd args').with(:line => 'LIBVIRTD_ARGS="--listen"') }
-        it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tls').with(:line => "listen_tls = 0") }
-        it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tcp').with(:line => "listen_tcp = 1") }
-        it { is_expected.not_to contain_file_line('/etc/libvirt/libvirtd.conf auth_tls')}
-        it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf auth_tcp').with(:line => "auth_tcp = \"none\"") }
       end
 
     end
@@ -420,34 +430,16 @@ describe 'nova::compute::libvirt' do
     :supported_os => OSDefaults.get_supported_os
   }).each do |os,facts|
     context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts())
+      end
 
-      case [:osfamily]
+      case facts[:osfamily]
       when 'Debian'
-
-        case [:operatingsystem]
-        when 'Debian'
-          let (:facts) do
-            facts.merge!(OSDefaults.get_facts({
-              :os_package_family => 'debian',
-              :operatingsystemmajrelease => '8'}))
-          end
-          it_behaves_like 'debian-nova-compute-libvirt'
-        when 'Ubuntu'
-          let (:facts) do
-            facts.merge!(OSDefaults.get_facts({
-              :os_package_family => 'ubuntu',
-              :operatingsystemmajrelease => '16.04'}))
-          end
-          it_behaves_like 'debian-nova-compute-libvirt'
-        end
-
+        it_behaves_like 'debian-nova-compute-libvirt'
       when 'RedHat'
-        let (:facts) do
-          facts.merge!(OSDefaults.get_facts({ :os_package_type => 'rpm' }))
-        end
         it_behaves_like 'redhat-nova-compute-libvirt'
       end
     end
   end
-
 end
