@@ -26,7 +26,7 @@ describe 'nova::cron::purge_shadow_tables' do
 
       it 'configures a nova purge cron with verbose output' do
         is_expected.to contain_cron('nova-manage db purge').with(
-          :command     => "nova-manage db purge --before `date --date='today - #{params[:age]} days' +%D` --verbose  >>#{params[:destination]} 2>&1",
+          :command     => "nova-manage db purge --before `date --date='today - #{params[:age]} days' +\\%D` --verbose  >>#{params[:destination]} 2>&1",
           :user        => 'nova',
           :environment => 'PATH=/bin:/usr/bin:/usr/sbin SHELL=/bin/sh',
           :user        => params[:user],
@@ -49,7 +49,7 @@ describe 'nova::cron::purge_shadow_tables' do
 
       it 'configures a nova purge cron without verbose output' do
         is_expected.to contain_cron('nova-manage db purge').with(
-          :command     => "nova-manage db purge --before `date --date='today - #{params[:age]} days' +%D`   >>#{params[:destination]} 2>&1",
+          :command     => "nova-manage db purge --before `date --date='today - #{params[:age]} days' +\\%D`   >>#{params[:destination]} 2>&1",
           :user        => 'nova',
           :environment => 'PATH=/bin:/usr/bin:/usr/sbin SHELL=/bin/sh',
           :user        => params[:user],
@@ -95,7 +95,7 @@ describe 'nova::cron::purge_shadow_tables' do
 
       it 'configures a nova purge cron with maxdelay' do
         is_expected.to contain_cron('nova-manage db purge').with(
-          :command     => "sleep `expr ${RANDOM} \\% #{params[:maxdelay]}`; nova-manage db purge --before `date --date='today - #{params[:age]} days' +%D` --verbose --all-cells >>#{params[:destination]} 2>&1",
+          :command     => "sleep `expr ${RANDOM} \\% #{params[:maxdelay]}`; nova-manage db purge --before `date --date='today - #{params[:age]} days' +\\%D` --verbose --all-cells >>#{params[:destination]} 2>&1",
           :environment => 'PATH=/bin:/usr/bin:/usr/sbin SHELL=/bin/sh',
           :user        => params[:user],
           :minute      => params[:minute],
