@@ -13,12 +13,12 @@ describe 'nova::db' do
       it { should_not contain_nova_config('api_database/connection') }
       it { should_not contain_nova_config('api_database/slave_connection') }
       it { should_not contain_nova_config('database/connection_recycle_time') }
-      it { should_not contain_nova_config('database/min_pool_size') }
       it { should_not contain_nova_config('database/max_pool_size') }
       it { should_not contain_nova_config('database/max_retries') }
       it { should_not contain_nova_config('database/retry_interval') }
       it { should_not contain_nova_config('database/max_overflow') }
       it { should_not contain_nova_config('database/pool_timeout') }
+      it { should_not contain_nova_config('database/mysql_enable_ndb') }
     end
 
     context 'with overridden parameters' do
@@ -36,16 +36,20 @@ describe 'nova::db' do
         :slave_connection        => 'mysql+pymysql://user:pass@slave/db1',
         :db_max_retries          => '<SERVICE DEFAULT>',
         :connection_recycle_time => '<SERVICE DEFAULT>',
-        :min_pool_size           => '<SERVICE DEFAULT>',
         :max_pool_size           => '<SERVICE DEFAULT>',
         :max_retries             => '<SERVICE DEFAULT>',
         :retry_interval          => '<SERVICE DEFAULT>',
         :max_overflow            => '<SERVICE DEFAULT>',
         :pool_timeout            => '<SERVICE DEFAULT>',
+        :mysql_enable_ndb        => '<SERVICE DEFAULT>',
       )}
 
-      it { should contain_nova_config('api_database/connection').with_value('mysql+pymysql://user:pass@db/db2').with_secret(true) }
-      it { should contain_nova_config('api_database/slave_connection').with_value('mysql+pymysql://user:pass@slave/db2').with_secret(true) }
+      it { should contain_oslo__db('api_database').with(
+        :config                  => 'nova_config',
+        :config_group            => 'api_database',
+        :connection              => 'mysql+pymysql://user:pass@db/db2',
+        :slave_connection        => 'mysql+pymysql://user:pass@slave/db2',
+      )}
     end
   end
 
