@@ -27,13 +27,12 @@ describe 'nova' do
         :refreshonly => true
       )}
 
-      it 'configures glance api servers' do
-        is_expected.to contain_nova_config('glance/api_servers').with_value('http://localhost:9292')
+      it 'does not configure glance api servers' do
+        is_expected.to_not contain_nova_config('glance/api_servers')
       end
 
-      it 'configures auth_strategy' do
-        is_expected.to contain_nova_config('api/auth_strategy').with_value('keystone')
-        is_expected.to_not contain_nova_config('DEFAULT/use_deprecated_auth').with_value(false)
+      it 'does not configure auth_strategy' do
+        is_expected.not_to contain_nova_config('api/auth_strategy')
       end
 
       it 'configures rabbit' do
@@ -44,6 +43,8 @@ describe 'nova' do
       end
 
       it 'configures various things' do
+        is_expected.to contain_nova_config('glance/endpoint_override').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('glance/num_retries').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/state_path').with_value('/var/lib/nova')
         is_expected.to contain_nova_config('oslo_concurrency/lock_path').with_value(platform_params[:lock_path])
         is_expected.to contain_nova_config('DEFAULT/service_down_time').with_value('60')
@@ -53,15 +54,15 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/control_exchange').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('cinder/os_region_name').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('cinder/cross_az_attach').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('cinder/catalog_info').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/cpu_allocation_ratio').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/ram_allocation_ratio').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/disk_allocation_ratio').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/ssl_only').with_value(false)
         is_expected.to contain_nova_config('DEFAULT/cert').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/key').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('console/ssl_ciphers').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('console/ssl_minimum_version').with_value('<SERVICE DEFAULT>')
       end
 
       it 'configures block_device_allocate params' do
@@ -74,7 +75,9 @@ describe 'nova' do
 
       let :params do
         {
-          :glance_api_servers                      => 'http://localhost:9292',
+          :glance_endpoint_override                => 'http://localhost:9292',
+          :glance_num_retries                      => 3,
+          :glance_api_servers                      => ['http://localhost:9292', 'http://localhost:9293'],
           :default_transport_url                   => 'rabbit://rabbit_user:password@localhost:5673',
           :rpc_response_timeout                    => '30',
           :control_exchange                        => 'nova',
@@ -92,14 +95,12 @@ describe 'nova' do
           :notification_topics                     => 'openstack',
           :notification_format                     => 'unversioned',
           :report_interval                         => '60',
-          :os_region_name                          => 'MyRegion',
-          :cross_az_attach                         => 'MyAZ',
+          :cross_az_attach                         => true,
           :ovsdb_connection                        => 'tcp:127.0.0.1:6640',
           :upgrade_level_cells                     => '1.0.0',
           :upgrade_level_cert                      => '1.0.0',
           :upgrade_level_compute                   => '1.0.0',
           :upgrade_level_conductor                 => '1.0.0',
-          :upgrade_level_console                   => '1.0.0',
           :upgrade_level_intercell                 => '1.0.0',
           :upgrade_level_network                   => '1.0.0',
           :upgrade_level_scheduler                 => '1.0.0',
@@ -110,6 +111,8 @@ describe 'nova' do
           :ssl_only                                => true,
           :cert                                    => '/etc/ssl/private/snakeoil.pem',
           :key                                     => '/etc/ssl/certs/snakeoil.pem',
+          :console_ssl_ciphers                     => 'kEECDH+aECDSA+AES:kEECDH+AES+aRSA:kEDH+aRSA+AES',
+          :console_ssl_minimum_version             => 'tlsv1_2',
         }
       end
 
@@ -124,19 +127,21 @@ describe 'nova' do
         })
       end
 
-      it 'configures glance api servers' do
-        is_expected.to contain_nova_config('glance/api_servers')
+      it 'configures glance parameters' do
+        is_expected.to contain_nova_config('glance/endpoint_override').with_value('http://localhost:9292')
+        is_expected.to contain_nova_config('glance/num_retries').with_value(3)
+        is_expected.to contain_nova_config('glance/api_servers').with_value(['http://localhost:9292', 'http://localhost:9293'])
       end
 
       it 'configures auth_strategy' do
         is_expected.to contain_nova_config('api/auth_strategy').with_value('foo')
-        is_expected.to_not contain_nova_config('DEFAULT/use_deprecated_auth').with_value(true)
       end
 
       it 'configures rabbit' do
         is_expected.to contain_nova_config('DEFAULT/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673')
         is_expected.to contain_nova_config('DEFAULT/rpc_response_timeout').with_value('30')
         is_expected.to contain_nova_config('DEFAULT/control_exchange').with_value('nova')
+        is_expected.to contain_nova_config('cinder/cross_az_attach').with_value(true)
         is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('60')
         is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_rate').with_value('10')
         is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_in_pthread').with_value(true)
@@ -155,7 +160,6 @@ describe 'nova' do
         is_expected.to contain_nova_config('upgrade_levels/cert').with_value('1.0.0')
         is_expected.to contain_nova_config('upgrade_levels/compute').with_value('1.0.0')
         is_expected.to contain_nova_config('upgrade_levels/conductor').with_value('1.0.0')
-        is_expected.to contain_nova_config('upgrade_levels/console').with_value('1.0.0')
         is_expected.to contain_nova_config('upgrade_levels/intercell').with_value('1.0.0')
         is_expected.to contain_nova_config('upgrade_levels/network').with_value('1.0.0')
         is_expected.to contain_nova_config('upgrade_levels/scheduler').with_value('1.0.0')
@@ -172,18 +176,18 @@ describe 'nova' do
         is_expected.to contain_nova_config('notifications/notification_format').with_value('unversioned')
         is_expected.to contain_nova_config('DEFAULT/report_interval').with_value('60')
         is_expected.to contain_nova_config('DEFAULT/ovsdb_connection').with_value('tcp:127.0.0.1:6640')
-        is_expected.to contain_nova_config('cinder/os_region_name').with_value('MyRegion')
-        is_expected.to contain_nova_config('cinder/cross_az_attach').with_value('MyAZ')
         is_expected.to contain_nova_config('DEFAULT/ssl_only').with_value(true)
         is_expected.to contain_nova_config('DEFAULT/cert').with_value('/etc/ssl/private/snakeoil.pem')
         is_expected.to contain_nova_config('DEFAULT/key').with_value('/etc/ssl/certs/snakeoil.pem')
+        is_expected.to contain_nova_config('console/ssl_ciphers').with_value('kEECDH+aECDSA+AES:kEECDH+AES+aRSA:kEDH+aRSA+AES')
+        is_expected.to contain_nova_config('console/ssl_minimum_version').with_value('tlsv1_2')
       end
 
       context 'with multiple notification_driver' do
         before { params.merge!( :notification_driver => ['ceilometer.compute.nova_notifier', 'nova.openstack.common.notifier.rpc_notifier']) }
 
         it { is_expected.to contain_nova_config('oslo_messaging_notifications/driver').with_value(
-          'ceilometer.compute.nova_notifier,nova.openstack.common.notifier.rpc_notifier'
+          ['ceilometer.compute.nova_notifier', 'nova.openstack.common.notifier.rpc_notifier']
         ) }
       end
 
