@@ -17,10 +17,14 @@ describe 'nova::policy' do
 
     it 'set up the policies' do
       is_expected.to contain_openstacklib__policy__base('context_is_admin').with({
-        :key   => 'context_is_admin',
-        :value => 'foo:bar'
+        :key        => 'context_is_admin',
+        :value      => 'foo:bar',
+        :file_user  => 'root',
+        :file_group => 'nova',
       })
-      is_expected.to contain_nova_config('oslo_policy/policy_file').with_value('/etc/nova/policy.json')
+      is_expected.to contain_oslo__policy('nova_config').with(
+        :policy_file => '/etc/nova/policy.json',
+      )
     end
   end
 
