@@ -10,7 +10,7 @@ describe provider_class do
     ENV['OS_USERNAME']     = 'test'
     ENV['OS_PASSWORD']     = 'abc123'
     ENV['OS_PROJECT_NAME'] = 'test'
-    ENV['OS_AUTH_URL']     = 'http://127.0.0.1:35357/v3'
+    ENV['OS_AUTH_URL']     = 'http://127.0.0.1:5000/v3'
   end
 
   describe 'managing aggregates' do
@@ -46,12 +46,13 @@ just,"simple","just"
             .returns('"id="just"
 name="simple"
 availability_zone=just"
-properties="key=\'2value\'"
+properties="key1=\'tomato\', key2=\'mushroom\'"
 hosts="[]"
 ')
           instances = provider_class.instances
           expect(instances.count).to eq(1)
           expect(instances[0].name).to eq('simple')
+          expect(instances[0].metadata).to eq({"key1"=>"tomato", "key2"=>"mushroom"})
         end
       end
 
@@ -95,6 +96,30 @@ hosts="[u\'example\']"
         end
       end
 
+      describe '#pythondict2hash' do
+        it 'should return a hash with key-value when provided with a unicode python dict' do
+          s = "{u'key': 'value', u'key2': 'value2'}"
+          expect(provider_class.pythondict2hash(s)).to eq({"key"=>"value", "key2"=>"value2"})
+        end
+
+        it 'should return a hash with key-value when provided with a python dict' do
+          s = "{'key': 'value', 'key2': 'value2'}"
+          expect(provider_class.pythondict2hash(s)).to eq({"key"=>"value", "key2"=>"value2"})
+        end
+      end
+
+      describe '#parsestring' do
+        it 'should call string2hash when provided with a string' do
+          s = "key='value', key2='value2'"
+          expect(provider_class.parsestring(s)).to eq({"key"=>"value", "key2"=>"value2"})
+        end
+
+        it 'should call pythondict2hash when provided with a hash' do
+          s = "{u'key': 'value', u'key2': 'value2'}"
+          expect(provider_class.parsestring(s)).to eq({"key"=>"value", "key2"=>"value2"})
+        end
+      end
+
     end
   end
 
